import markdown
import extension
import re

MAIN_HTML = """
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="en" xml:lang="en">

<head>
	<meta http-equiv="Content-type" content="application/xhtml+xml;charset=utf-8" />
	<title>{title} — Spyware Watchdog</title>
	<link rel="stylesheet" href="../style.css" />
</head>

<body>
	<div class="case">
		<div class="nav">
			<a href="index.html">&larr; Catalog</a>
		</div>

		<div class="main">
			<img src="../images/{fileName}_logo.png" alt="{title}'s Logo" />
			<h1>{title}</h1>
			{introduction}
			<h2>Spyware Level: {spywareLevel}</h2>
			{content}
		</div>

		<div class="footer">
			{footer}
			<hr>
			<p>If you want to edit this article, or contribute your own article(s), visit us at the git repo on <a href="https://codeberg.org/shadow/SpywareWatchdog">Codeberg</a>.</p>
			<p>All contributions must be licensed under the CC0 license to be accepted.</p>
			<a href="../LICENSE.txt"><img class="icon" src="../images/cc0.png" alt="CC0 License" /></a>
		</div>
	</div>
</body>

</html>
"""

md = markdown.Markdown(extensions=[extension.ArticleMarkdown()]) # The extension which adds various features to the markdown

regex = r"Title: (.+)\nRating: (\d+)\nCatagory: (.+)\nCreated: (.+)\nModified: (.+)\nVersion: (.+)\nIntroduction:\n([\s\S]*)Content:\n([\s\S]*)Further:\n([\s\S]*)Sources:\n([\s\S]*)"

def convertMarkdown(inputStr, fileName):
	result = re.match(regex, inputStr, re.MULTILINE)
	title = result.group(1)
	rating = result.group(2)
	catagory = result.group(3)
	created = result.group(4)
	modified = result.group(5)
	version = result.group(6)
	introduction = result.group(7)
	content = result.group(8)
	further = result.group(9)
	sources = result.group(10)

	footer = ""

	# Futher reading
	footer += """<hr>
<div class="futher">
	<h4>Further Reading:</h4>
	{further}
</div>
""".format(further = md.convert(further).replace("\n","\n\t")).replace("\n", "\n\t\t\t")

	# Sources
	a = ""
	for i in sources.split("\n"):
		if i != "":
			result = re.match(r"(\d+)\. (.+)", i)
			a += """\n<li id="source{number}">{content}</li>""".format(
				number = result.group(1),
				content = md.convert(result.group(2))
			).replace("\n", "\n\t\t")

	footer += f"""<hr>
<div class="sources">
	<h4>Sources:</h4>
	<ol>{a}
	</ol>
</div>
""".replace("\n", "\n\t\t\t")
	
	# dates
	footer += f"""<hr>
<b>This article was created on {created}</b></br>
<b>This article was last modified on {modified}</b></br>  
<b>This article is made for version {version} of the software</b>""".replace("\n", "\n\t\t\t")

	# The .replace is used below to make sure indentation is consistent
	# This is not required but makes debugging a little easier.
	return MAIN_HTML.format(
		title = title,
		fileName = fileName,
		spywareLevel = rating,
		introduction = md.convert(introduction).replace("\n", "\n\t\t\t"),
		content = md.convert(content).replace("\n", "\n\t\t\t"),
		footer = footer
	)

open("chrome.html", "w", encoding="utf8").write(
	convertMarkdown(
		open("./chrome.md", encoding="utf8").read(), 
		"chrome"
	)
)